'use strict';

exports.__esModule = true;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactStyleProptype = require('react-style-proptype');

var _reactStyleProptype2 = _interopRequireDefault(_reactStyleProptype);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Creates a stepper.
 * @param {array} steps - Names of different steps.
 * @param {number} activeStep - Index of the active step.
 * @param {string} className - Classname of the component.
 * @param {string} styleComponent - Style of the component.
 * @param {string} styleStep - Style of the step box.
 * @param {string} styleLine - Style of the line between step boxes.
 * @param {string} styleActive - Active style step.
 * @returns {ReactElement} - Stepper generated
 */
var Stepper = function Stepper(_ref) {
  var steps = _ref.steps,
      activeStep = _ref.activeStep,
      className = _ref.className,
      styleComponent = _ref.styleComponent,
      styleStep = _ref.styleStep,
      styleLine = _ref.styleLine,
      styleActive = _ref.styleActive;

  var stepsLines = steps.reduce(function (r, a) {
    return r.concat(a, false);
  }, []);
  stepsLines.pop();

  return _react2.default.createElement(
    'div',
    { style: styleComponent, className: 'Stepper ' + className },
    stepsLines.map(function (step, i) {
      return i % 2 ? _react2.default.createElement('div', {
        key: i,
        style: _extends({}, styleLine, ++activeStep >= i ? styleActive : {})
      }) : _react2.default.createElement(
        'div',
        {
          key: i,
          style: _extends({}, styleStep, activeStep >= i ? styleActive : {})
        },
        step
      );
    })
  );
};

Stepper.propTypes = process.env.NODE_ENV !== "production" ? {
  // State
  steps: _propTypes2.default.arrayOf(_propTypes2.default.string).isRequired,
  activeStep: _propTypes2.default.number.isRequired,

  // Modifiers
  className: _propTypes2.default.string,
  styleComponent: _reactStyleProptype2.default,
  styleStep: _reactStyleProptype2.default,
  styleLine: _reactStyleProptype2.default,
  styleActive: _reactStyleProptype2.default
} : {};

Stepper.defaultProps = {
  // Modifiers
  className: '',
  styleComponent: {
    display: 'flex',
    justifyContent: 'space-around',
    flexFlow: 'row wrap',
    margin: '10px 20px',
    alignItems: 'center'
  },
  styleStep: {
    background: '#6e6e6e',
    color: '#fff',
    flexShrink: 1,
    padding: '10px 14px',
    borderRadius: '7px'
  },
  styleLine: {
    height: '2px',
    background: '#6e6e6e',
    flexGrow: 1
  },
  styleActive: {
    background: '#4f96ff'
  }
};

exports.default = Stepper;
module.exports = exports['default'];